==> w3css_paragraphs-1.0.0.tar.gz: w3css_paragraphs/modules/w3css_paragraphs_views/README.md <==
# INTRODUCTION

The W3CSS Paragraphs module provides a suite of paragraph bundles made with the
W3.CSS front-end framework. You have the power to create unlimited UI design
by using the paragraph bundle features.

The parent module w3css_paragraphs has the first two basic paragraph bundles
(Text and Image) All other children bundles are in a separate bundle/module.
All images are using the media module.

Combine the power of the w3.css front end framework with Drupal Paragraphs,
the powerful module that allows content creators to build layouts and
structured pages.

Using the w3.css Paragraphs Drupal module, you'll be able to create in less than
minutes features like Slideshow, Accordions, Hero Banner, Image Overlay,
Parallax, 3D Carousels, Modals, Tabs (Horizontal or Vertical), 3D Flip Box,
One Column Layout, Two Columns Layout and Three Columns Layout.

Bundle Types: for each bundle type I created a demo, feel free to check it.

W3CSS Paragraphs 3D Carousel Bundle (Images)
W3CSS Paragraphs 3D Carousel Bundle (Text)
W3CSS Paragraphs 3D Flip Box Bundle
W3CSS Paragraphs Accordion Bundle
W3CSS Paragraphs Card Bundle
W3CSS Paragraphs Contact Form Bundle
W3CSS Paragraphs Drupal Block Bundle
W3CSS Paragraphs Hero Bundle
W3CSS Paragraphs Image Bundle
W3CSS Paragraphs Image Overlay Bundle
W3CSS Paragraphs Modal Bundle
W3CSS Paragraphs Parallax Bundle
W3CSS Paragraphs Simple Bundle
W3CSS Paragraphs Slideshow Bundle
W3CSS Paragraphs Tabs Bundle (Horizontal or Vertical)
W3CSS Paragraphs One Column Bundle
W3CSS Paragraphs Three Columns Bundle
W3CSS Paragraphs Two Columns Bundle
W3CSS Paragraphs Quicklinks Bundle
W3CSS Paragraphs Views Bundle
W3CSS Paragraphs Weborm Bundle

Bundle Type Features: some paragraph bundles may have more or less.
Background colors: 30 Colors to choose from.
Background color Hover: 30 Colors to choose from.
Text colors: 30 Colors to choose from.
Text color hover: 30 Colors to choose from.
Border color: 30 Colors to choose from.
Border color hover: 30 Colors to choose from.
Background color opacity: after you choose the background color you can choose
the opacity for the background color. 5% - 10% - 20% - 30% - 40% - 50% - 60% -
70% - 80% - 90% - 95% (11 x 30 = 330 total colors you can create.) The opacity
will be applied to the background color only.
Width: 30% - 40% - 50% - 60% - 70% - 80% - 90% - 100%.
Borders: 11 styles to choose from.
Round Borders: 6 Styles to choose from.
Margin: 6 styles to choose from
Padding: 8 styles to choose from.
Card: Add 2px or 4px bordered shadow.
W3CSS Classes: One extra field for any w3.css classes.


# DEPENDENCIES
W3CSS Theme: https://www.drupal.org/project/d8w3css
W3CSS Paragraphs: https://www.drupal.org/project/w3css_paragraphs
Paragraphs: https://www.drupal.org/project/paragraphs
Field Group: https://www.drupal.org/project/field_group
Views Reference: https://www.drupal.org/project/viewsreference

# INSTALLATION
Install as any other contrib module.

==> w3css_paragraphs-1.0.3.tar.gz: w3css_paragraphs/modules/w3css_paragraphs_views/README.md <==
# INTRODUCTION

The W3CSS Paragraphs module provides a suite of paragraph bundles made with the
W3.CSS front-end framework. You have the power to create unlimited UI design
by using the paragraph bundle features.

The parent module w3css_paragraphs has the first two basic paragraph bundles
(Text and Image) All other children bundles are in a separate bundle/module.
All images are using the media module.

Combine the power of the w3.css front end framework with Drupal Paragraphs,
the powerful module that allows content creators to build layouts and
structured pages.

Using the w3.css Paragraphs Drupal module, you'll be able to create in less than
minutes features like Slideshow, Accordions, Hero Banner, Image Overlay,
Parallax, 3D Carousels, Modals, Tabs (Horizontal or Vertical), 3D Flip Box,
One Column Layout, Two Columns Layout and Three Columns Layout.

Bundle Types: for each bundle type I created a demo, feel free to check it.

W3CSS Paragraphs 3D Carousel Bundle (Images)
W3CSS Paragraphs 3D Carousel Bundle (Text)
W3CSS Paragraphs 3D Flip Box Bundle
W3CSS Paragraphs Accordion Bundle
W3CSS Paragraphs Card Bundle
W3CSS Paragraphs Contact Form Bundle
W3CSS Paragraphs Drupal Block Bundle
W3CSS Paragraphs Hero Bundle
W3CSS Paragraphs Image Bundle
W3CSS Paragraphs Image Overlay Bundle
W3CSS Paragraphs Modal Bundle
W3CSS Paragraphs Parallax Bundle
W3CSS Paragraphs Simple Bundle
W3CSS Paragraphs Slideshow Bundle
W3CSS Paragraphs Tabs Bundle (Horizontal or Vertical)
W3CSS Paragraphs One Column Bundle
W3CSS Paragraphs Three Columns Bundle
W3CSS Paragraphs Two Columns Bundle
W3CSS Paragraphs Quicklinks Bundle
W3CSS Paragraphs Views Bundle
W3CSS Paragraphs Webform Bundle

Bundle Type Features: some paragraph bundles may have more or less.
Background colors: 30 Colors to choose from.
Background color Hover: 30 Colors to choose from.
Text colors: 30 Colors to choose from.
Text color hover: 30 Colors to choose from.
Border color: 30 Colors to choose from.
Border color hover: 30 Colors to choose from.
Background color opacity: after you choose the background color you can choose
the opacity for the background color. 5% - 10% - 20% - 30% - 40% - 50% - 60% -
70% - 80% - 90% - 95% (11 x 30 = 330 total colors you can create.) The opacity
will be applied to the background color only.
Width: 30% - 40% - 50% - 60% - 70% - 80% - 90% - 100%.
Borders: 11 styles to choose from.
Round Borders: 6 Styles to choose from.
Margin: 6 styles to choose from
Padding: 8 styles to choose from.
Card: Add 2px or 4px bordered shadow.
W3CSS Classes: One extra field for any w3.css classes.


# DEPENDENCIES
W3CSS Theme: https://www.drupal.org/project/d8w3css
W3CSS Paragraphs: https://www.drupal.org/project/w3css_paragraphs
Paragraphs: https://www.drupal.org/project/paragraphs
Field Group: https://www.drupal.org/project/field_group
Views Reference: https://www.drupal.org/project/viewsreference

# INSTALLATION
Install as any other contrib module.
